@@ -76,8 +76,8 @@ Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA */
 // TODO: remove non-wrapping versions?
 #define SPC_NO_SP_WRAPAROUND 0
 
-#define SET_SP( v )     (sp = ram + 0x101 + (v))
-#define GET_SP()        (sp - 0x101 - ram)
+#define SET_SP( v )     (sp = ram + 0x101 + ((uint8_t) v))
+#define GET_SP()        (uint8_t) (sp - 0x101 - ram)
 
 #if SPC_NO_SP_WRAPAROUND
 #define PUSH16( v )     (sp -= 2, SET_LE16( sp, v ))
@@ -172,33 +172,33 @@ SPC_CPU_RUN_FUNC
 	int c;
 	int nz;
 	int dp;
-	
+
 	SET_PC( m.cpu_regs.pc );
 	SET_SP( m.cpu_regs.sp );
 	SET_PSW( m.cpu_regs.psw );
-	
+
 	goto loop;
-	
-	
+
+
 	// Main loop
-	
+
 cbranch_taken_loop:
-	pc += *(BOOST::int8_t const*) pc;
+	pc += *(int8_t const*) pc;
 inc_pc_loop:
 	pc++;
 loop:
 {
 	unsigned opcode;
 	unsigned data;
-	
+
 	check( (unsigned) a < 0x100 );
 	check( (unsigned) x < 0x100 );
 	check( (unsigned) y < 0x100 );
-	
+
 	opcode = *pc;
 	if ( (rel_time += m.cycle_table [opcode]) > 0 )
 		goto out_of_time;
-	
+
 	#ifdef SPC_CPU_OPCODE_HOOK
 		SPC_CPU_OPCODE_HOOK( GET_PC(), opcode );
 	#endif
@@ -211,43 +211,43 @@ loop:
 				pc [len] == 0xF0 && pc [len+1] == 0xFE - len;\
 		SUB_CASE_COUNTER( op && cond );\
 	}
-	
+
 	PROFILE_TIMER_LOOP( 0xEC, GET_LE16( pc + 1 ), 3 );
 	PROFILE_TIMER_LOOP( 0xEB, pc [1], 2 );
 	PROFILE_TIMER_LOOP( 0xE4, pc [1], 2 );
 	*/
-	
+
 	// TODO: if PC is at end of memory, this will get wrong operand (very obscure)
 	data = *++pc;
 	switch ( opcode )
 	{
-	
+
 // Common instructions
 
 #define BRANCH( cond )\
 {\
 	pc++;\
-	pc += (BOOST::int8_t) data;\
+	pc += (int8_t) data;\
 	if ( cond )\
 		goto loop;\
-	pc -= (BOOST::int8_t) data;\
+	pc -= (int8_t) data;\
 	rel_time -= 2;\
 	goto loop;\
 }
 
 	case 0xF0: // BEQ
 		BRANCH( !(uint8_t) nz ) // 89% taken
-	
+
 	case 0xD0: // BNE
 		BRANCH( (uint8_t) nz )
-	
+
 	case 0x3F:{// CALL
 		int old_addr = GET_PC() + 2;
 		SET_PC( READ_PC16( pc ) );
 		PUSH16( old_addr );
 		goto loop;
 	}
-	
+
 	case 0x6F:// RET
 		#if SPC_NO_SP_WRAPAROUND
 		{
@@ -261,19 +261,19 @@ loop:
 			sp += 2;
 			if ( addr < 0x1FF )
 				goto loop;
-			
+
 			SET_PC( sp [-0x101] * 0x100 + ram [(uint8_t) addr + 0x100] );
 			sp -= 0x100;
 		}
 		#endif
 		goto loop;
-	
+
 	case 0xE4: // MOV a,dp
 		++pc;
 		// 80% from timer
 		READ_DP_TIMER( 0, data, a = nz );
 		goto loop;
-	
+
 	case 0xFA:{// MOV dp,dp
 		int temp;
 		READ_DP_TIMER( -2, data, temp );
@@ -283,7 +283,7 @@ loop:
 	case 0x8F:{// MOV dp,#imm
 		int temp = READ_PC( pc + 1 );
 		pc += 2;
-		
+
 		#if !SPC_MORE_ACCURACY
 		{
 			int i = dp + temp;
@@ -292,7 +292,7 @@ loop:
 			if ( (unsigned) i < 0x10 ) // 76%
 			{
 				REGS [i] = (uint8_t) data;
-				
+
 				// Registers other than $F2 and $F4-$F7
 				//if ( i != 2 && i != 4 && i != 5 && i != 6 && i != 7 )
 				if ( ((~0x2F00 << (bits_in_int - 16)) << i) < 0 ) // 12%
@@ -304,7 +304,7 @@ loop:
 		#endif
 		goto loop;
 	}
-	
+
 	case 0xC4: // MOV dp,a
 		++pc;
 		#if !SPC_MORE_ACCURACY
@@ -316,7 +316,7 @@ loop:
 			{
 				unsigned sel = i - 2;
 				REGS [i] = (uint8_t) a;
-				
+
 				if ( sel == 1 ) // 51% $F3
 					dsp_write( a, rel_time );
 				else if ( sel > 1 ) // 1% not $F2 or $F3
@@ -327,7 +327,7 @@ loop:
 			WRITE_DP( 0, data, a );
 		#endif
 		goto loop;
-	
+
 #define CASE( n )   case n:
 
 // Define common address modes based on opcode for immediate mode. Execution
@@ -371,25 +371,25 @@ loop:
 	ADDR_MODES_NO_DP( 0xE8 ) // MOV A,addr
 		a = nz = READ( 0, data );
 		goto inc_pc_loop;
-	
+
 	case 0xBF:{// MOV A,(X)+
 		int temp = x + dp;
 		x = (uint8_t) (x + 1);
 		a = nz = READ( -1, temp );
 		goto loop;
 	}
-	
+
 	case 0xE8: // MOV A,imm
 		a  = data;
 		nz = data;
 		goto inc_pc_loop;
-	
+
 	case 0xF9: // MOV X,dp+Y
 		data = (uint8_t) (data + y);
 	case 0xF8: // MOV X,dp
 		READ_DP_TIMER( 0, data, x = nz );
 		goto inc_pc_loop;
-	
+
 	case 0xE9: // MOV X,abs
 		data = READ_PC16( pc );
 		++pc;
@@ -398,7 +398,7 @@ loop:
 		x  = data;
 		nz = data;
 		goto inc_pc_loop;
-	
+
 	case 0xFB: // MOV Y,dp+X
 		data = (uint8_t) (data + x);
 	case 0xEB: // MOV Y,dp
@@ -406,7 +406,7 @@ loop:
 		pc++;
 		READ_DP_TIMER( 0, data, y = nz );
 		goto loop;
-	
+
 	case 0xEC:{// MOV Y,abs
 		int temp = READ_PC16( pc );
 		pc += 2;
@@ -414,18 +414,18 @@ loop:
 		//y = nz = READ( 0, temp );
 		goto loop;
 	}
-	
+
 	case 0x8D: // MOV Y,imm
 		y  = data;
 		nz = data;
 		goto inc_pc_loop;
-	
+
 // 2. 8-BIT DATA TRANSMISSION COMMANDS, GROUP 2
 
 	ADDR_MODES_NO_DP( 0xC8 ) // MOV addr,A
 		WRITE( 0, data, a );
 		goto inc_pc_loop;
-	
+
 	{
 		int temp;
 	case 0xCC: // MOV abs,Y
@@ -438,13 +438,13 @@ loop:
 		pc += 2;
 		goto loop;
 	}
-	
+
 	case 0xD9: // MOV dp+Y,X
 		data = (uint8_t) (data + y);
 	case 0xD8: // MOV dp,X
 		WRITE( 0, data + dp, x );
 		goto inc_pc_loop;
-	
+
 	case 0xDB: // MOV dp+X,Y
 		data = (uint8_t) (data + x);
 	case 0xCB: // MOV dp,Y
@@ -452,44 +452,44 @@ loop:
 		goto inc_pc_loop;
 
 // 3. 8-BIT DATA TRANSMISSIN COMMANDS, GROUP 3.
-	
+
 	case 0x7D: // MOV A,X
 		a  = x;
 		nz = x;
 		goto loop;
-	
+
 	case 0xDD: // MOV A,Y
 		a  = y;
 		nz = y;
 		goto loop;
-	
+
 	case 0x5D: // MOV X,A
 		x  = a;
 		nz = a;
 		goto loop;
-	
+
 	case 0xFD: // MOV Y,A
 		y  = a;
 		nz = a;
 		goto loop;
-	
+
 	case 0x9D: // MOV X,SP
 		x = nz = GET_SP();
 		goto loop;
-	
+
 	case 0xBD: // MOV SP,X
 		SET_SP( x );
 		goto loop;
-	
+
 	//case 0xC6: // MOV (X),A (handled by MOV addr,A in group 2)
-	
+
 	case 0xAF: // MOV (X)+,A
 		WRITE_DP( 0, x, a + no_read_before_write  );
-		x++;
+		x = (uint8_t) (x + 1);
 		goto loop;
-	
+
 // 5. 8-BIT LOGIC OPERATION COMMANDS
-	
+
 #define LOGICAL_OP( op, func )\
 	ADDR_MODES( op ) /* addr */\
 		data = READ( 0, data );\
@@ -513,13 +513,13 @@ loop:
 		WRITE( 0, addr, nz );\
 		goto loop;\
 	}
-	
+
 	LOGICAL_OP( 0x28, & ); // AND
-	
+
 	LOGICAL_OP( 0x08, | ); // OR
-	
+
 	LOGICAL_OP( 0x48, ^ ); // EOR
-	
+
 // 4. 8-BIT ARITHMETIC OPERATION COMMANDS
 
 	ADDR_MODES( 0x68 ) // CMP addr
@@ -529,14 +529,14 @@ loop:
 		c = ~nz;
 		nz &= 0xFF;
 		goto inc_pc_loop;
-	
+
 	case 0x79: // CMP (X),(Y)
 		data = READ_DP( -2, y );
 		nz = READ_DP( -1, x ) - data;
 		c = ~nz;
 		nz &= 0xFF;
 		goto loop;
-	
+
 	case 0x69: // CMP dp,dp
 		data = READ_DP( -3, data );
 	case 0x78: // CMP dp,imm
@@ -544,7 +544,7 @@ loop:
 		c = ~nz;
 		nz &= 0xFF;
 		goto inc_pc_loop;
-	
+
 	case 0x3E: // CMP X,dp
 		data += dp;
 		goto cmp_x_addr;
@@ -558,7 +558,7 @@ loop:
 		c = ~nz;
 		nz &= 0xFF;
 		goto inc_pc_loop;
-	
+
 	case 0x7E: // CMP Y,dp
 		data += dp;
 		goto cmp_y_addr;
@@ -572,7 +572,7 @@ loop:
 		c = ~nz;
 		nz &= 0xFF;
 		goto inc_pc_loop;
-	
+
 	{
 		int addr;
 	case 0xB9: // SBC (x),(y)
@@ -590,7 +590,7 @@ loop:
 	adc_addr:
 		nz = READ( -1, addr );
 		goto adc_data;
-		
+
 // catch ADC and SBC together, then decode later based on operand
 #undef CASE
 #define CASE( n ) case n: case (n) + 0x20:
@@ -604,11 +604,11 @@ loop:
 		int flags;
 		if ( opcode >= 0xA0 ) // SBC
 			data ^= 0xFF;
-		
+
 		flags = data ^ nz;
 		nz += data + (c >> 8 & 1);
 		flags ^= nz;
-		
+
 		psw = (psw & ~(v40 | h08)) |
 				(flags >> 1 & h08) |
 				((flags + 0x80) >> 2 & v40);
@@ -621,9 +621,9 @@ loop:
 		WRITE( 0, addr, /*(uint8_t)*/ nz );
 		goto inc_pc_loop;
 	}
-	
+
 	}
-	
+
 // 6. ADDITION & SUBTRACTION COMMANDS
 
 #define INC_DEC_REG( reg, op )\
@@ -634,7 +634,7 @@ loop:
 	case 0xBC: INC_DEC_REG( a, + 1 ) // INC A
 	case 0x3D: INC_DEC_REG( x, + 1 ) // INC X
 	case 0xFC: INC_DEC_REG( y, + 1 ) // INC Y
-	
+
 	case 0x9C: INC_DEC_REG( a, - 1 ) // DEC A
 	case 0x1D: INC_DEC_REG( x, - 1 ) // DEC X
 	case 0xDC: INC_DEC_REG( y, - 1 ) // DEC Y
@@ -655,7 +655,7 @@ loop:
 		nz += READ( -1, data );
 		WRITE( 0, data, /*(uint8_t)*/ nz );
 		goto inc_pc_loop;
-	
+
 // 7. SHIFT, ROTATION COMMANDS
 
 	case 0x5C: // LSR A
@@ -666,7 +666,7 @@ loop:
 		a = nz;
 		goto loop;
 	}
-	
+
 	case 0x1C: // ASL A
 		c = 0;
 	case 0x3C:{// ROL A
@@ -676,7 +676,7 @@ loop:
 		a = (uint8_t) nz;
 		goto loop;
 	}
-	
+
 	case 0x0B: // ASL dp
 		c = 0;
 		data += dp;
@@ -698,7 +698,7 @@ loop:
 		nz |= (c = READ( -1, data ) << 1);
 		WRITE( 0, data, /*(uint8_t)*/ nz );
 		goto inc_pc_loop;
-	
+
 	case 0x4B: // LSR dp
 		c = 0;
 		data += dp;
@@ -735,12 +735,12 @@ loop:
 		y = READ_DP( 0, (uint8_t) (data + 1) );
 		nz |= y;
 		goto inc_pc_loop;
-	
+
 	case 0xDA: // MOVW dp,YA
 		WRITE_DP( -1, data, a );
 		WRITE_DP( 0, (uint8_t) (data + 1), y + no_read_before_write  );
 		goto inc_pc_loop;
-	
+
 // 9. 16-BIT OPERATION COMMANDS
 
 	case 0x3A: // INCW dp
@@ -752,33 +752,33 @@ loop:
 		temp += (opcode >> 4 & 2) - 1; // +1 for INCW, -1 for DECW
 		nz = ((temp >> 1) | temp) & 0x7F;
 		WRITE( -2, data, /*(uint8_t)*/ temp );
-		
+
 		// high byte
 		data = (uint8_t) (data + 1) + dp;
 		temp = (uint8_t) ((temp >> 8) + READ( -1, data ));
 		nz |= temp;
 		WRITE( 0, data, temp );
-		
+
 		goto inc_pc_loop;
 	}
-		
+
 	case 0x7A: // ADDW YA,dp
 	case 0x9A:{// SUBW YA,dp
 		int lo = READ_DP( -2, data );
 		int hi = READ_DP( 0, (uint8_t) (data + 1) );
 		int result;
 		int flags;
-		
+
 		if ( opcode == 0x9A ) // SUBW
 		{
 			lo = (lo ^ 0xFF) + 1;
 			hi ^= 0xFF;
 		}
-		
+
 		lo += a;
 		result = y + hi + (lo >> 8);
 		flags = hi ^ y ^ result;
-		
+
 		psw = (psw & ~(v40 | h08)) |
 				(flags >> 1 & h08) |
 				((flags + 0x80) >> 2 & v40);
@@ -787,10 +787,10 @@ loop:
 		result = (uint8_t) result;
 		y = result;
 		nz = (((lo >> 1) | lo) & 0x7F) | result;
-		
+
 		goto inc_pc_loop;
 	}
-	
+
 	case 0x5A: { // CMPW YA,dp
 		int temp = a - READ_DP( -1, data );
 		nz = ((temp >> 1) | temp) & 0x7F;
@@ -801,30 +801,30 @@ loop:
 		nz &= 0xFF;
 		goto inc_pc_loop;
 	}
-	
+
 // 10. MULTIPLICATION & DIVISON COMMANDS
 
 	case 0xCF: { // MUL YA
 		unsigned temp = y * a;
 		a = (uint8_t) temp;
 		nz = ((temp >> 1) | temp) & 0x7F;
-		y = temp >> 8;
+		y = (uint8_t) (temp >> 8);
 		nz |= y;
 		goto loop;
 	}
-	
+
 	case 0x9E: // DIV YA,X
 	{
 		unsigned ya = y * 0x100 + a;
-		
+
 		psw &= ~(h08 | v40);
-		
+
 		if ( y >= x )
 			psw |= v40;
-		
+
 		if ( (y & 15) >= (x & 15) )
 			psw |= h08;
-		
+
 		if ( y < x * 2 )
 		{
 			a = ya / x;
@@ -835,15 +835,16 @@ loop:
 			a = 255 - (ya - x * 0x200) / (256 - x);
 			y = x   + (ya - x * 0x200) % (256 - x);
 		}
-		
+
 		nz = (uint8_t) a;
 		a = (uint8_t) a;
-		
+		y = (uint8_t) y;
+
 		goto loop;
 	}
-	
+
 // 11. DECIMAL COMPENSATION COMMANDS
-	
+
 	case 0xDF: // DAA
 		SUSPICIOUS_OPCODE( "DAA" );
 		if ( a > 0x99 || c & 0x100 )
@@ -851,14 +852,14 @@ loop:
 			a += 0x60;
 			c = 0x100;
 		}
-		
+
 		if ( (a & 0x0F) > 9 || psw & h08 )
 			a += 0x06;
-		
+
 		nz = a;
 		a = (uint8_t) a;
 		goto loop;
-	
+
 	case 0xBE: // DAS
 		SUSPICIOUS_OPCODE( "DAS" );
 		if ( a > 0x99 || !(c & 0x100) )
@@ -866,38 +867,38 @@ loop:
 			a -= 0x60;
 			c = 0;
 		}
-		
+
 		if ( (a & 0x0F) > 9 || !(psw & h08) )
 			a -= 0x06;
-		
+
 		nz = a;
 		a = (uint8_t) a;
 		goto loop;
-	
+
 // 12. BRANCHING COMMANDS
 
 	case 0x2F: // BRA rel
-		pc += (BOOST::int8_t) data;
+		pc += (int8_t) data;
 		goto inc_pc_loop;
-	
+
 	case 0x30: // BMI
 		BRANCH( (nz & nz_neg_mask) )
-	
+
 	case 0x10: // BPL
 		BRANCH( !(nz & nz_neg_mask) )
-	
+
 	case 0xB0: // BCS
 		BRANCH( c & 0x100 )
-	
+
 	case 0x90: // BCC
 		BRANCH( !(c & 0x100) )
-	
+
 	case 0x70: // BVS
 		BRANCH( psw & v40 )
-	
+
 	case 0x50: // BVC
 		BRANCH( !(psw & v40) )
-	
+
 	#define CBRANCH( cond )\
 	{\
 		pc++;\
@@ -906,7 +907,7 @@ loop:
 		rel_time -= 2;\
 		goto inc_pc_loop;\
 	}
-	
+
 	case 0x03: // BBS dp.bit,rel
 	case 0x23:
 	case 0x43:
@@ -916,7 +917,7 @@ loop:
 	case 0xC3:
 	case 0xE3:
 		CBRANCH( READ_DP( -4, data ) >> (opcode >> 5) & 1 )
-	
+
 	case 0x13: // BBC dp.bit,rel
 	case 0x33:
 	case 0x53:
@@ -926,7 +927,7 @@ loop:
 	case 0xD3:
 	case 0xF3:
 		CBRANCH( !(READ_DP( -4, data ) >> (opcode >> 5) & 1) )
-	
+
 	case 0xDE: // CBNE dp+X,rel
 		data = (uint8_t) (data + x);
 		// fall through
@@ -936,26 +937,26 @@ loop:
 		READ_DP_TIMER( -4, data, temp );
 		CBRANCH( temp != a )
 	}
-	
+
 	case 0x6E: { // DBNZ dp,rel
 		unsigned temp = READ_DP( -4, data ) - 1;
 		WRITE_DP( -3, (uint8_t) data, /*(uint8_t)*/ temp + no_read_before_write  );
 		CBRANCH( temp )
 	}
-	
+
 	case 0xFE: // DBNZ Y,rel
 		y = (uint8_t) (y - 1);
 		BRANCH( y )
-	
+
 	case 0x1F: // JMP [abs+X]
 		SET_PC( READ_PC16( pc ) + x );
 		// fall through
 	case 0x5F: // JMP abs
 		SET_PC( READ_PC16( pc ) );
 		goto loop;
-	
+
 // 13. SUB-ROUTINE CALL RETURN COMMANDS
-	
+
 	case 0x0F:{// BRK
 		int temp;
 		int ret_addr = GET_PC();
@@ -967,14 +968,14 @@ loop:
 		PUSH( temp );
 		goto loop;
 	}
-	
+
 	case 0x4F:{// PCALL offset
 		int ret_addr = GET_PC() + 1;
 		SET_PC( 0xFF00 | data );
 		PUSH16( ret_addr );
 		goto loop;
 	}
-	
+
 	case 0x01: // TCALL n
 	case 0x11:
 	case 0x21:
@@ -996,7 +997,7 @@ loop:
 		PUSH16( ret_addr );
 		goto loop;
 	}
-	
+
 // 14. STACK OPERATION COMMANDS
 
 	{
@@ -1004,7 +1005,7 @@ loop:
 	case 0x7F: // RET1
 		temp = *sp;
 		SET_PC( GET_LE16( sp + 1 ) );
-		sp += 3;
+		SET_SP( GET_SP() + 3 );
 		goto set_psw;
 	case 0x8E: // POP PSW
 		POP( temp );
@@ -1012,7 +1013,7 @@ loop:
 		SET_PSW( temp );
 		goto loop;
 	}
-	
+
 	case 0x0D: { // PUSH PSW
 		int temp;
 		GET_PSW( temp );
@@ -1023,27 +1024,27 @@ loop:
 	case 0x2D: // PUSH A
 		PUSH( a );
 		goto loop;
-	
+
 	case 0x4D: // PUSH X
 		PUSH( x );
 		goto loop;
-	
+
 	case 0x6D: // PUSH Y
 		PUSH( y );
 		goto loop;
-	
+
 	case 0xAE: // POP A
 		POP( a );
 		goto loop;
-	
+
 	case 0xCE: // POP X
 		POP( x );
 		goto loop;
-	
+
 	case 0xEE: // POP Y
 		POP( y );
 		goto loop;
-	
+
 // 15. BIT OPERATION COMMANDS
 
 	case 0x02: // SET1
@@ -1070,7 +1071,7 @@ loop:
 		WRITE( 0, data, (READ( -1, data ) & mask) | bit );
 		goto inc_pc_loop;
 	}
-		
+
 	case 0x0E: // TSET1 abs
 	case 0x4E: // TCLR1 abs
 		data = READ_PC16( pc );
@@ -1084,32 +1085,32 @@ loop:
 			WRITE( 0, data, temp );
 		}
 		goto loop;
-	
+
 	case 0x4A: // AND1 C,mem.bit
 		c &= MEM_BIT( 0 );
 		pc += 2;
 		goto loop;
-	
+
 	case 0x6A: // AND1 C,/mem.bit
 		c &= ~MEM_BIT( 0 );
 		pc += 2;
 		goto loop;
-	
+
 	case 0x0A: // OR1 C,mem.bit
 		c |= MEM_BIT( -1 );
 		pc += 2;
 		goto loop;
-	
+
 	case 0x2A: // OR1 C,/mem.bit
 		c |= ~MEM_BIT( -1 );
 		pc += 2;
 		goto loop;
-	
+
 	case 0x8A: // EOR1 C,mem.bit
 		c ^= MEM_BIT( -1 );
 		pc += 2;
 		goto loop;
-	
+
 	case 0xEA: // NOT1 mem.bit
 		data = READ_PC16( pc );
 		pc += 2;
@@ -1119,7 +1120,7 @@ loop:
 			WRITE( 0, data & 0x1FFF, temp );
 		}
 		goto loop;
-	
+
 	case 0xCA: // MOV1 mem.bit,C
 		data = READ_PC16( pc );
 		pc += 2;
@@ -1130,53 +1131,53 @@ loop:
 			WRITE( 0, data & 0x1FFF, temp + no_read_before_write  );
 		}
 		goto loop;
-	
+
 	case 0xAA: // MOV1 C,mem.bit
 		c = MEM_BIT( 0 );
 		pc += 2;
 		goto loop;
-	
+
 // 16. PROGRAM PSW FLAG OPERATION COMMANDS
 
 	case 0x60: // CLRC
 		c = 0;
 		goto loop;
-		
+
 	case 0x80: // SETC
 		c = ~0;
 		goto loop;
-	
+
 	case 0xED: // NOTC
 		c ^= 0x100;
 		goto loop;
-		
+
 	case 0xE0: // CLRV
 		psw &= ~(v40 | h08);
 		goto loop;
-	
+
 	case 0x20: // CLRP
 		dp = 0;
 		goto loop;
-	
+
 	case 0x40: // SETP
 		dp = 0x100;
 		goto loop;
-	
+
 	case 0xA0: // EI
 		SUSPICIOUS_OPCODE( "EI" );
 		psw |= i04;
 		goto loop;
-	
+
 	case 0xC0: // DI
 		SUSPICIOUS_OPCODE( "DI" );
 		psw &= ~i04;
 		goto loop;
-	
+
 // 17. OTHER COMMANDS
 
 	case 0x00: // NOP
 		goto loop;
-	
+
 	case 0xFF:{// STOP
 		// handle PC wrap-around
 		unsigned addr = GET_PC() - 1;
@@ -1196,13 +1197,13 @@ loop:
 		m.cpu_error = "SPC emulation error";
 		goto stop;
 	} // switch
-	
+
 	assert( 0 ); // catch any unhandled instructions
-}   
+}
 out_of_time:
 	rel_time -= m.cycle_table [*pc]; // undo partial execution of opcode
 stop:
-	
+
 	// Uncache registers
 	if ( GET_PC() >= 0x10000 )
 		debug_printf( "SPC: PC wrapped around\n" );
