@@ -666,6 +666,9 @@ const char * const FFaudio::exts[] = {
     /* atrac3 */
     "aa3", "oma",
 
+    /* Advanced Audio Coding */
+    "aac",
+
     /* MPEG 2/4 AC3 */
     "ac3",
 
@@ -682,7 +685,7 @@ const char * const FFaudio::exts[] = {
     "vqf",
 
     /* MPEG-4 */
-    "m4a", "m4v", "mp4",
+    "m4a", "mp4",
 
     /* WAV (there are some WAV formats sndfile can't handle) */
     "wav",
@@ -690,9 +693,6 @@ const char * const FFaudio::exts[] = {
     /* Handle OGG streams (FLAC/Vorbis etc.) */
     "ogg", "oga",
 
-    /* Opus */
-    "opus",
-
     /* Speex */
     "spx",
 
@@ -711,6 +711,7 @@ const char * const FFaudio::exts[] = {
 
 const char * const FFaudio::mimes[] = {
     "application/ogg",
+    "audio/aac",
     "audio/mp4",
     "audio/ogg",
     nullptr
