@@ -49,7 +49,8 @@ const char * const pw_col_names[PW_COLS] = {
     N_("Bitrate"),
     N_("Comment"),
     N_("Publisher"),
-    N_("Catalog Number")
+    N_("Catalog Number"),
+    N_("Disc")
 };
 
 int pw_num_cols;
@@ -73,7 +74,8 @@ static const char * const pw_col_keys[PW_COLS] = {
     "bitrate",
     "comment",
     "publisher",
-    "catalog-number"
+    "catalog-number",
+    "disc"
 };
 
 static const int pw_default_widths[PW_COLS] = {
@@ -93,7 +95,8 @@ static const int pw_default_widths[PW_COLS] = {
     10,   // bitrate
     275,  // comment
     175,  // publisher
-    75   // catalog number
+    75,   // catalog number
+    10    // disc
 };
 
 void pw_col_init ()
