@@ -24,6 +24,8 @@
  * SUCH DAMAGE.
  */
 
+#include <string.h>
+
 #include <libaudcore/i18n.h>
 #include <libaudcore/plugin.h>
 #include <libaudcore/preferences.h>
@@ -86,9 +88,11 @@ public:
 
         tuple.set_filename(filename);
         tuple.set_format(mpt.format(), mpt.channels(), mpt.rate(), 0);
-
         tuple.set_int(Tuple::Length, mpt.duration());
-        tuple.set_str(Tuple::Title, mpt.title());
+
+        const String &title = mpt.title();
+        if (strlen(title) > 0)
+            tuple.set_str(Tuple::Title, title);
 
         return true;
     }
@@ -152,7 +156,6 @@ const PreferencesWidget MPTPlugin::widgets[] =
             WidgetInt(CFG_SECTION, SETTING_STEREO_SEPARATION, values_changed),
             { 0.0, 200.0, 1.0, N_("% (0=mono, 100=default, 200=full)") }
     ),
-
     WidgetCombo(
             N_("Interpolation:"),
             WidgetInt(CFG_SECTION, SETTING_INTERPOLATOR, values_changed),
