@@ -29,7 +29,7 @@
 
 #define _IN_DMA
 
-extern uint32_t psx_ram[(2*1024*1024)/4];
+extern uint32_t psx_ram[(2*1024*1024)/4+4];
 
 //#include "externals.h"
 ////////////////////////////////////////////////////////////////////////
