@@ -39,6 +39,7 @@ public:
 private:
     PlaylistWidget * m_playlist;
     bool m_inUpdate = false;
+    bool m_inStyleChange = false;
     int m_lastCol = -1;
 
     void sectionClicked(int logicalIndex);
@@ -46,9 +47,15 @@ private:
     void sectionResized(int logicalIndex, int /*oldSize*/, int newSize);
 
     void contextMenuEvent(QContextMenuEvent * event);
+    bool event(QEvent * event);
 
-    const HookReceiver<PlaylistHeader> hook1{
-        "qtui update playlist columns", this, &PlaylistHeader::updateColumns};
+    void updateStyle();
+
+    const HookReceiver<PlaylistHeader> //
+        hook1{"qtui update playlist columns", this,
+              &PlaylistHeader::updateColumns},
+        hook2{"qtui update playlist headers", this,
+              &PlaylistHeader::updateStyle};
 };
 
 #endif // PLAYLIST_HEADER_H
