@@ -23,14 +23,14 @@
 #include <libaudcore/i18n.h>
 #include <libaudcore/preferences.h>
 
-#include <QApplication>
-#include <QDesktopWidget>
-
 const char * const qtui_defaults[] = {
     // clang-format off
     "infoarea_show_vis", "TRUE",
+    "infoarea_show_art", "TRUE",
     "infoarea_visible", "TRUE",
     "menu_visible", "TRUE",
+    "player_width", "768",
+    "player_height", "480",
     "playlist_tabs_visible", aud::numeric_string<PlaylistTabVisibility::AutoHide>::str,
     "statusbar_visible", "TRUE",
     "entry_count_visible", "FALSE",
@@ -39,6 +39,8 @@ const char * const qtui_defaults[] = {
     "autoscroll", "TRUE",
     "playlist_columns", DEFAULT_COLUMNS,
     "playlist_headers", "TRUE",
+    "playlist_headers_bold", "FALSE",
+    "playlist_headers_sortable", "TRUE",
     "show_remaining_time", "FALSE",
     // clang-format on
     nullptr};
@@ -48,6 +50,11 @@ static void qtui_update_playlist_settings()
     hook_call("qtui update playlist settings", nullptr);
 }
 
+static void qtui_update_playlist_headers()
+{
+    hook_call("qtui update playlist headers", nullptr);
+}
+
 static const ComboItem playlist_tabs_options[] = {
     ComboItem(N_("Always"), PlaylistTabVisibility::Always),
     ComboItem(N_("Auto-hide"), PlaylistTabVisibility::AutoHide),
@@ -69,6 +76,12 @@ static const PreferencesWidget qtui_widgets[] = {
     WidgetCheck(
         N_("Show column headers"),
         WidgetBool("qtui", "playlist_headers", qtui_update_playlist_settings)),
+    WidgetCheck(N_("Use bold font for column headers"),
+                WidgetBool("qtui", "playlist_headers_bold",
+                           qtui_update_playlist_headers)),
+    WidgetCheck(N_("Make column headers clickable for sorting"),
+                WidgetBool("qtui", "playlist_headers_sortable",
+                           qtui_update_playlist_settings)),
     WidgetLabel(N_("<b>Miscellaneous</b>")),
     WidgetCheck(N_("Scroll on song change"), WidgetBool("qtui", "autoscroll"))};
 
