@@ -44,6 +44,9 @@ public:
 
     TimeSliderLabel * label() { return m_label; }
 
+protected:
+    void wheelEvent(QWheelEvent * event);
+
 private:
     void set_label(int time, int length);
 
@@ -55,10 +58,12 @@ private:
 
     TimeSliderLabel * m_label;
 
+    int m_scroll_delta = 0;
+
     const Timer<TimeSlider> m_timer{TimerRate::Hz4, this, &TimeSlider::update};
 
-    const HookReceiver<TimeSlider> hook1{"playback ready", this,
-                                         &TimeSlider::start_stop},
+    const HookReceiver<TimeSlider> //
+        hook1{"playback ready", this, &TimeSlider::start_stop},
         hook2{"playback pause", this, &TimeSlider::start_stop},
         hook3{"playback unpause", this, &TimeSlider::start_stop},
         hook4{"playback seek", this, &TimeSlider::update},
