@@ -1,3 +1,11 @@
+/*
+ * Scrobbler Plugin v2.0 for Audacious by Pitxyoki
+ *
+ * Copyright 2012-2013 Luís Picciochi Oliveira <Pitxyoki@Gmail.com>
+ *
+ * This plugin is part of the Audacious Media Player.
+ * It is licensed under the GNU General Public License, version 3.
+ */
 
 //external includes
 #include <stdarg.h>
@@ -7,6 +15,7 @@
 
 #include <glib.h>
 
+//audacious includes
 #include <libaudcore/audstrings.h>
 #include <libaudcore/interface.h>
 
@@ -26,11 +35,8 @@ gboolean scrobbling_enabled = true;
 char *received_data = nullptr;   //Holds the result of the last request made to last.fm
 size_t received_data_size = 0; //Holds the size of the received_data buffer
 
-
-
 // The cURL callback function to store the received data from the last.fm servers.
 static size_t result_callback (void *buffer, size_t size, size_t nmemb, void *userp) {
-
     const size_t len = size*nmemb;
 
     char *temp_data = g_renew(char, received_data, received_data_size + len + 1);
@@ -146,7 +152,7 @@ static gboolean scrobbler_request_token ()
 
     if (read_token(error_code, error_detail) == false) {
         success = false;
-        if (error_code != nullptr && g_strcmp0(error_code, "8")) {
+        if (error_code && g_strcmp0(error_code, "8")) {
             //error code 8: There was an error granting the request token. Please try again later
             request_token = String();
         }
@@ -155,14 +161,13 @@ static gboolean scrobbler_request_token ()
     return success;
 }
 
-
 static gboolean update_session_key() {
     gboolean result = true;
     String error_code;
     String error_detail;
 
     if (read_session_key(error_code, error_detail) == false) {
-        if (error_code != nullptr && (
+        if (error_code && (
                 g_strcmp0(error_code,  "4") == 0 || //invalid token
                 g_strcmp0(error_code, "14") == 0 || //token not authorized
                 g_strcmp0(error_code, "15") == 0    //token expired
@@ -203,7 +208,6 @@ static gboolean scrobbler_request_session ()
 //sets scrobbling_enabled to TRUE if the session is OK
 //sets session_key to nullptr if it is invalid
 static gboolean scrobbler_test_connection() {
-
     if (!session_key || !session_key[0]) {
         scrobbling_enabled = false;
         return true;
@@ -230,7 +234,7 @@ static gboolean scrobbler_test_connection() {
     if (read_authentication_test_result(error_code, error_detail) == false) {
         AUDINFO("Error code: %s. Detail: %s.\n", (const char *)error_code,
          (const char *)error_detail);
-        if (error_code != nullptr && (
+        if (error_code && (
                 g_strcmp0(error_code, "4") == 0 || //error code 4: Authentication Failed - You do not have permissions to access the service
                 g_strcmp0(error_code, "9") == 0    //error code 9: Invalid session key - Please re-authenticate
             )) {
@@ -282,8 +286,8 @@ gboolean scrobbler_communication_init() {
 }
 
 static void set_timestamp_to_current(char **line) {
-    //line[0] line[1] line[2] line[3] line[4] line[5] line[6]   line[7]
-    //artist  album   title   number  length  "L"     timestamp nullptr
+    //line[0] line[1] line[2] line[3] line[4] line[5] line[6]   line[7]      line[8]
+    //artist  album   title   number  length  "L"     timestamp album_artist nullptr
 
     char **split_line = g_strsplit(*line, "\t", 0);
     g_free(split_line[6]);
@@ -309,7 +313,6 @@ static void delete_lines_from_scrobble_log (GSList **lines_to_remove_ptr, GSList
         lines_to_retry = g_slist_reverse(lines_to_retry);
     }
 
-
     pthread_mutex_lock(&log_access_mutex);
 
     gboolean success = g_file_get_contents(queuepath, &contents, nullptr, nullptr);
@@ -319,7 +322,9 @@ static void delete_lines_from_scrobble_log (GSList **lines_to_remove_ptr, GSList
         lines = g_strsplit(contents, "\n", 0);
 
         n_finallines = 0;
-        for (int i = 0 ; lines[i] != nullptr && strlen(lines[i]) > 0; i++) {
+        for (int i = 0 ; lines[i] != nullptr; i++) {
+            if (!strlen(lines[i])) continue;
+
             if (lines_to_remove != nullptr && *((int *) (lines_to_remove->data)) == i) {
                 //this line is to remove
                 lines_to_remove = g_slist_next(lines_to_remove);
@@ -333,7 +338,6 @@ static void delete_lines_from_scrobble_log (GSList **lines_to_remove_ptr, GSList
                   AUDDBG("Line before: %s.\n", lines[i]);
                   set_timestamp_to_current(&(lines[i]));
                   AUDDBG("Line after: %s.\n", lines[i]);
-
                 } else {
                   AUDDBG("not zeroing this line\n");
                 }
@@ -352,12 +356,10 @@ static void delete_lines_from_scrobble_log (GSList **lines_to_remove_ptr, GSList
         if (!success) {
             AUDERR("Could not write to scrobbler.log!\n");
         }
-
     }
 
     pthread_mutex_unlock(&log_access_mutex);
 
-
     g_strfreev(finallines);
     g_strfreev(lines);
     g_free(contents);
@@ -369,8 +371,25 @@ static void save_line_to_remove(GSList **lines_to_remove, int linenumber) {
     (*lines_to_remove) = g_slist_prepend((*lines_to_remove), rem);
 }
 
-static void scrobble_cached_queue() {
+static gboolean is_valid_scrobble_format(char **line) {
+    if (line == nullptr) return false;
 
+    guint num_fields = g_strv_length(line);
+
+    //in normal circumstances cache entry is expected to have 8 fields,
+    //but allow entries with 7 fields (i.e. without album artist) for compatibility with old cache format
+    if (num_fields != 8 && num_fields != 7) return false;
+
+    //string literal "L" in the 6th field is part of scrobbler.log format
+    if (g_strcmp0(line[5], "L") != 0) return false;
+
+    //artist, title and timestamp are mandatory parameters of last.fm track.Scrobble API
+    if (!strlen(line[0]) || !strlen(line[2]) || !strlen(line[6])) return false;
+
+    return true;
+}
+
+static void scrobble_cached_queue() {
     char *queuepath = g_build_filename(aud_get_path(AudPath::UserDir),"scrobbler.log", nullptr);
     char *contents = nullptr;
     gboolean success;
@@ -382,25 +401,28 @@ static void scrobble_cached_queue() {
     pthread_mutex_lock(&log_access_mutex);
     success = g_file_get_contents(queuepath, &contents, nullptr, nullptr);
     pthread_mutex_unlock(&log_access_mutex);
+
     if (!success) {
         AUDDBG("Couldn't access the queue file.\n");
     } else {
-
         lines = g_strsplit(contents, "\n", 0);
 
-        for (int i = 0; lines[i] != nullptr && strlen(lines[i]) > 0 && scrobbling_enabled; i++) {
+        for (int i = 0; lines[i] != nullptr && scrobbling_enabled; i++) {
+            if (!strlen(lines[i])) continue;
+
             line = g_strsplit(lines[i], "\t", 0);
 
-            //line[0] line[1] line[2] line[3] line[4] line[5] line[6]   line[7]
-            //artist  album   title   number  length  "L"     timestamp nullptr
+            //line[0] line[1] line[2] line[3] line[4] line[5] line[6]   line[7]      line[8]
+            //artist  album   title   number  length  "L"     timestamp album_artist nullptr
 
-            if (line[0] && line[2] && (strcmp(line[5], "L") == 0) && line[6] && (line[7] == nullptr))
+            if (is_valid_scrobble_format(line))
             {
                 String scrobblemsg = create_message_to_lastfm ("track.scrobble",
-                 8, "artist", line[0], "album", line[1], "track", line[2],
+                 9, "artist", line[0], "album", line[1], "track", line[2],
                  "trackNumber", line[3], "duration", line[4],
-                 "timestamp", line[6], "api_key", SCROBBLER_API_KEY,
-                 "sk", (const char *) session_key);
+                 "timestamp", line[6],
+                 "albumArtist", line[7] != nullptr ? line[7] : "",  //in case cache uses old format without album artist field
+                 "api_key", SCROBBLER_API_KEY, "sk", (const char *) session_key);
 
                 if (send_message_to_lastfm(scrobblemsg) == true) {
                     String error_code;
@@ -423,7 +445,6 @@ static void scrobble_cached_queue() {
                            //This message comes on the ignoredMessage attribute, inside the XML of the response.
                            //We are not dealing with this case currently and are losing that scrobble.
                            //TODO
-
                         } else {
                             AUDDBG("Not ignored. Carrying on...\n");
                             save_line_to_remove(&lines_to_remove, i);
@@ -467,7 +488,6 @@ static void scrobble_cached_queue() {
             g_strfreev(line);
         }//for
 
-
         delete_lines_from_scrobble_log(&lines_to_remove, &lines_to_retry, queuepath);
 
         if (lines_to_remove != nullptr) {
@@ -484,9 +504,7 @@ static void scrobble_cached_queue() {
     g_free(queuepath);
 }
 
-
 static void send_now_playing() {
-
   String error_code;
   String error_detail;
   gboolean ignored = false;
@@ -503,6 +521,7 @@ static void send_now_playing() {
   StringBuf artist = clean_string (curr_track.get_str (Tuple::Artist));
   StringBuf title = clean_string (curr_track.get_str (Tuple::Title));
   StringBuf album = clean_string (curr_track.get_str (Tuple::Album));
+  StringBuf album_artist = clean_string (curr_track.get_str (Tuple::AlbumArtist));
 
   int track  = curr_track.get_int (Tuple::Track);
   int length = curr_track.get_int (Tuple::Length);
@@ -511,11 +530,11 @@ static void send_now_playing() {
     StringBuf track_str = (track > 0) ? int_to_str (track) : StringBuf (0);
     StringBuf length_str = int_to_str (length / 1000);
 
-    String playingmsg = create_message_to_lastfm ("track.updateNowPlaying", 7,
+    String playingmsg = create_message_to_lastfm ("track.updateNowPlaying", 8,
      "artist", (const char *) artist, "album", (const char *) album,
      "track", (const char *) title, "trackNumber", (const char *) track_str,
-     "duration", (const char *) length_str, "api_key", SCROBBLER_API_KEY,
-     "sk", (const char *) session_key);
+     "duration", (const char *) length_str, "albumArtist", (const char *) album_artist,
+     "api_key", SCROBBLER_API_KEY, "sk", (const char *) session_key);
 
     gboolean success = send_message_to_lastfm(playingmsg);
 
@@ -537,10 +556,8 @@ static void send_now_playing() {
         session_key = String();
         aud_set_str("scrobbler", "session_key", "");
       }
-
     }
     //We don't care if the now playing was not accepted, no need to read the result from the server.
-
   }
 }
 
@@ -552,10 +569,8 @@ static void treat_permission_check_request() {
             if (scrobbler_request_token() == false || !request_token || !request_token[0]) {
                 perm_result = PERMISSION_NONET;
             } //else PERMISSION_DENIED
-
         } else if (scrobbler_request_session() == false) {
             perm_result = PERMISSION_NONET;
-
         } else if (!session_key || !session_key[0]) {
             //This means we had a token, a session was requested now,
             //but the token was not accepted or expired.
@@ -574,7 +589,6 @@ static void treat_permission_check_request() {
                     perm_result = PERMISSION_DENIED;
                 } //else PERMISSION_NONET
             }
-
         } else {
             if (scrobbling_enabled) {
                 perm_result = PERMISSION_ALLOWED;
@@ -597,65 +611,21 @@ static void treat_permission_check_request() {
     } //session_key == nullptr || strlen(session_key) == 0
 }
 
-// This is a sister function of scrobbler_request_session, using the getMobileSession
-//API call, for migrating from the old config
-//returns:
-// FALSE if there was a network problem OR a session_key was not obtained
-// TRUE if a new session_key was obtained
-static gboolean treat_migrate_config() {
-
-    String password = aud_get_str("audioscrobbler","password");
-    String username = aud_get_str("audioscrobbler","username");
-    if (!password[0] || !username[0])
-        return false;
-
-    char *checksumThis = g_strdup_printf("%s%s", (const char *)username, (const char *)password);
-    char *authToken = g_compute_checksum_for_string(G_CHECKSUM_MD5, checksumThis, -1);
-
-    String sessionmsg = create_message_to_lastfm ("auth.getMobileSession", 3,
-     "authToken", authToken, "username", (const char *) username,
-     "api_key", SCROBBLER_API_KEY);
-
-    g_free(checksumThis);
-    g_free(authToken);
-
-    if (send_message_to_lastfm(sessionmsg) == false)
-        return false;
-
-    if (!update_session_key())
-        return false;
-
-    return (session_key && session_key[0]);
-}
-
-
 //Scrobbling will only be enabled after the first connection test passed
 void * scrobbling_thread (void * input_data) {
-
     while (scrobbler_running) {
-
-        if (migrate_config_requested) {
-          if (treat_migrate_config() == false) {
-            aud_ui_show_error(_("Audacious is now using an improved version of the Last.fm Scrobbler.\nPlease check the Preferences for the Scrobbler plugin."));
-          }
-          aud_set_str("scrobbler", "migrated", "true");
-          migrate_config_requested = false;
-
-        } else if (permission_check_requested) {
+        if (permission_check_requested) {
             treat_permission_check_request();
             permission_check_requested = false;
-
         } else if (invalidate_session_requested) {
             session_key = String();
             aud_set_str("scrobbler", "session_key", "");
             invalidate_session_requested = false;
-
         } else if (now_playing_requested) {
             if (scrobbling_enabled) {
               send_now_playing();
             }
             now_playing_requested = false;
-
         } else {
             if (scrobbling_enabled) {
               scrobble_cached_queue();
@@ -697,4 +667,3 @@ void * scrobbling_thread (void * input_data) {
     scrobbling_enabled = true;
     return nullptr;
 }
-
