@@ -1,3 +1,11 @@
+/*
+ * Scrobbler Plugin v2.0 for Audacious by Pitxyoki
+ *
+ * Copyright 2012-2013 Luís Picciochi Oliveira <Pitxyoki@Gmail.com>
+ *
+ * This plugin is part of the Audacious Media Player.
+ * It is licensed under the GNU General Public License, version 3.
+ */
 
 //plugin includes
 #include "scrobbler.h"
@@ -10,7 +18,7 @@ static gboolean prepare_data () {
     received_data[received_data_size] = '\0';
     AUDDBG("Data received from last.fm:\n%s\n%%%%End of data%%%%\n", received_data);
 
-    doc = xmlParseMemory(received_data, received_data_size+1);
+    doc = xmlReadMemory(received_data, received_data_size, nullptr, nullptr, 0);
     received_data_size = 0;
     if (doc == nullptr) {
         AUDDBG("Document not parsed successfully.\n");
@@ -24,6 +32,7 @@ static gboolean prepare_data () {
         doc = nullptr;
         return false;
     }
+
     return true;
 }
 
@@ -34,7 +43,6 @@ static void clean_data() {
     doc = nullptr;
 }
 
-
 //returns:
 // nullptr if an error occurs or the attribute was not found
 // the attribute's value if it was found
@@ -100,13 +108,11 @@ static String get_node_string (const char *node_expression) {
     return result;
 }
 
-
 //returns:
 // nullptr if an error occurs
 // "true" if the the command succeeded
 // "false" if an error occurred. error_code and error_detail should be checked in this case
 static String check_status (String &error_code, String &error_detail) {
-
     String status = get_attribute_value("/lfm[@status]", "status");
     if (!status) {
         AUDDBG("last.fm not answering according to the API.\n");
@@ -115,7 +121,6 @@ static String check_status (String &error_code, String &error_detail) {
 
     AUDDBG ("status is %s.\n", (const char *)status);
     if (strcmp(status, "ok")) {
-
         error_code = get_attribute_value("/lfm/error[@code]", "code");
         if (!(*error_code)) {
             AUDDBG("Weird API answer. Last.fm says status is %s but there is no error code?\n",
@@ -143,7 +148,6 @@ static String check_status (String &error_code, String &error_detail) {
  */
 gboolean read_scrobble_result(String &error_code, String &error_detail,
  gboolean *ignored, String &ignored_code) {
-
     *ignored = false;
 
     gboolean result = true;
@@ -165,7 +169,6 @@ gboolean read_scrobble_result(String &error_code, String &error_detail,
         AUDDBG("Error code: %s. Detail: %s.\n", (const char *)error_code,
          (const char *)error_detail);
         result = false;
-
     } else {
         //TODO: We are assuming that only one track is scrobbled per request! This will have to be
         //re-done to support multiple tracks being scrobbled in batch
@@ -188,7 +191,6 @@ gboolean read_scrobble_result(String &error_code, String &error_detail,
 //returns
 //FALSE if there was an error with the connection
 gboolean read_authentication_test_result (String &error_code, String &error_detail) {
-
     gboolean result = true;
 
     if (!prepare_data()) {
@@ -206,7 +208,6 @@ gboolean read_authentication_test_result (String &error_code, String &error_deta
 
     if (!strcmp(status, "failed")) {
         result = false;
-
     } else {
         username = get_node_string("/lfm/user/name");
         if (!username) {
@@ -219,10 +220,7 @@ gboolean read_authentication_test_result (String &error_code, String &error_deta
     return result;
 }
 
-
-
 gboolean read_token (String &error_code, String &error_detail) {
-
     gboolean result = true;
 
     if (!prepare_data()) {
@@ -259,10 +257,7 @@ gboolean read_token (String &error_code, String &error_detail) {
     return result;
 }
 
-
-
 gboolean read_session_key(String &error_code, String &error_detail) {
-
     gboolean result = true;
 
     if (!prepare_data()) {
@@ -282,7 +277,6 @@ gboolean read_session_key(String &error_code, String &error_detail) {
         AUDDBG("Error code: %s. Detail: %s.\n", (const char *)error_code,
          (const char *)error_detail);
         result = false;
-
     } else {
         session_key = get_node_string("/lfm/session/key");
 
@@ -297,4 +291,3 @@ gboolean read_session_key(String &error_code, String &error_detail) {
     clean_data();
     return result;
 }
-
