@@ -1,14 +1,6 @@
 #ifndef XS_CONFIG_H
 #define XS_CONFIG_H
 
-#include <pthread.h>
-#include <libaudcore/core.h>
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-
 /* Configuration structure
  */
 enum XS_CHANNELS {
@@ -40,42 +32,33 @@ extern struct xs_cfg_t {
     int     audioFrequency;
 
     /* Emulation settings */
-    bool_t  mos8580;            /* TRUE = 8580, FALSE = 6581 */
-    bool_t  forceModel;
+    bool    mos8580;            /* true = 8580, false = 6581 */
+    bool    forceModel;
     int     clockSpeed;         /* PAL (50Hz) or NTSC (60Hz) */
-    bool_t  forceSpeed;         /* TRUE = force to given clockspeed */
+    bool    forceSpeed;         /* true = force to given clockspeed */
 
-    bool_t  emulateFilters;
+    bool    emulateFilters;
 
     /* Playing settings */
-    bool_t  playMaxTimeEnable,
+    bool    playMaxTimeEnable,
             playMaxTimeUnknown; /* Use max-time only when song-length is unknown */
     int     playMaxTime;        /* MAX playtime in seconds */
 
-    bool_t  playMinTimeEnable;
+    bool    playMinTimeEnable;
     int     playMinTime;        /* MIN playtime in seconds */
 
-    bool_t  songlenDBEnable;
-    char    *songlenDBPath;     /* Path to Songlengths.txt */
-
     /* Miscellaneous settings */
-    bool_t  stilDBEnable;
-    char    *stilDBPath;        /* Path to STIL.txt */
-    char    *hvscPath;          /* Path-prefix for HVSC */
-
-    bool_t  subAutoEnable,
+    bool    subAutoEnable,
             subAutoMinOnly;
     int     subAutoMinTime;
 } xs_cfg;
 
-extern pthread_mutex_t xs_cfg_mutex;
-
 
 /* Functions
  */
-void xs_init_configuration(void);
+void xs_init_configuration();
+
+struct PluginPreferences;
+extern const PluginPreferences sid_prefs;
 
-#ifdef __cplusplus
-}
-#endif
 #endif    /* XS_CONFIG_H */
