@@ -351,3 +351,23 @@ void dock_change_scale (int old_scale, int new_scale)
         }
     }
 }
+
+void dock_draw_all ()
+{
+    for (DockWindow & dw : windows)
+    {
+        if (dw.window)
+            dw.window->queue_draw ();
+    }
+}
+
+bool dock_is_focused ()
+{
+    for (DockWindow & dw : windows)
+    {
+        if (dw.window && dw.window->isActiveWindow ())
+            return true;
+    }
+
+    return false;
+}
