@@ -21,18 +21,10 @@
 #ifndef PLUGIN_SKINS_H
 #define PLUGIN_SKINS_H
 
-#include <glib.h>
+const char * skins_get_user_skin_dir ();
+const char * skins_get_skin_thumb_dir ();
 
-enum {
-    SKINS_PATH_USER_SKIN_DIR,
-    SKINS_PATH_SKIN_THUMB_DIR,
-    SKINS_PATH_COUNT
-};
-
-extern char * skins_paths[];
-
-void skins_restart (void);
-
-gboolean handle_window_close (void);
+void skins_restart ();
+void skins_close ();
 
 #endif
